---
name: Request support for data repository
about: Suggest a repository to support in Datahugger
title: "[NEW REPOSITORY REQUEST]"
labels: enhancement, help wanted
assignees: ''

---

**What's the name and URL of the repository?**


**Does the repository support DOIs? If so, please provide one or more DOIs**


**Are you interested in implementing support for this repository in Datahugger**
Feel free to say no. Maybe other readers are interested in implementing this.
